Package: SEMID
Type: Package
Title: Identifiability of Linear Structural Equation Models
Version: 0.4.1
Date: 2023-07-19
Authors@R: c(person("Rina", "Foygel Barber", role=c("aut"), 
                   email="rina@uchicago.edu"), 
            person("Mathias", "Drton", role=c("aut"), 
                   email="mathias.drton@tum.de"), 
            person("Luca", "Weihs", role=c("aut"), 
                   email="lucaw@allenai.org"), 
            person("Nils", "Sturma", role=c("cre", "aut"), 
                    email="nils.sturma@tum.de"))
Maintainer: Nils Sturma <nils.sturma@tum.de>
Description: Provides routines to check identifiability or non-identifiability
    of linear structural equation models as described in Drton, Foygel, and
    Sullivant (2011) <doi:10.1214/10-AOS859>, Foygel, Draisma, and Drton (2012) 
    <doi:10.1214/12-AOS1012>, and other works. The routines are based on the graphical 
    representation of structural equation models.
License: GPL (>= 2)
Encoding: UTF-8
URL: https://github.com/Lucaweihs/SEMID
BugReports: https://github.com/Lucaweihs/SEMID/issues
Imports: R.oo (>= 1.20.0), R.methodsS3, igraph (>= 1.0.1), R.utils (>=
        2.3.0)
Suggests: testthat
NeedsCompilation: no
Repository: CRAN
RoxygenNote: 7.2.3
Packaged: 2023-07-19 12:11:35 UTC; nilssturma
Author: Rina Foygel Barber [aut],
  Mathias Drton [aut],
  Luca Weihs [aut],
  Nils Sturma [cre, aut]
Date/Publication: 2023-07-19 14:00:11 UTC
Built: R 4.4.0; ; 2024-05-04 10:23:05 UTC; unix
