# Generated by roxygen2: do not edit by hand

S3method(L,LatentDigraph)
S3method(L,LatentDigraphFixedOrder)
S3method(L,MixedGraph)
S3method(O,MixedGraph)
S3method(ancestors,LatentDigraph)
S3method(ancestors,LatentDigraphFixedOrder)
S3method(ancestors,MixedGraph)
S3method(children,LatentDigraph)
S3method(children,LatentDigraphFixedOrder)
S3method(children,MixedGraph)
S3method(createTrGraph,LatentDigraphFixedOrder)
S3method(createTrekFlowGraph,LatentDigraphFixedOrder)
S3method(descendants,LatentDigraph)
S3method(descendants,LatentDigraphFixedOrder)
S3method(descendants,MixedGraph)
S3method(flowBetween,FlowGraph)
S3method(getHalfTrekSystem,MixedGraph)
S3method(getMixedGraph,LatentDigraph)
S3method(getTrekSystem,LatentDigraph)
S3method(getTrekSystem,LatentDigraphFixedOrder)
S3method(getTrekSystem,MixedGraph)
S3method(htrFrom,MixedGraph)
S3method(inducedSubgraph,LatentDigraph)
S3method(inducedSubgraph,MixedGraph)
S3method(isSibling,MixedGraph)
S3method(latentNodes,LatentDigraph)
S3method(nodes,MixedGraph)
S3method(numLatents,LatentDigraph)
S3method(numLatents,LatentDigraphFixedOrder)
S3method(numNodes,LatentDigraph)
S3method(numNodes,LatentDigraphFixedOrder)
S3method(numNodes,MixedGraph)
S3method(numObserved,LatentDigraph)
S3method(numObserved,LatentDigraphFixedOrder)
S3method(observedNodes,LatentDigraph)
S3method(observedParents,LatentDigraph)
S3method(parents,LatentDigraph)
S3method(parents,LatentDigraphFixedOrder)
S3method(parents,MixedGraph)
S3method(plot,LatentDigraph)
S3method(plot,MixedGraph)
S3method(print,GenericIDResult)
S3method(print,LfhtcIDResult)
S3method(print,SEMIDResult)
S3method(siblings,MixedGraph)
S3method(stronglyConnectedComponent,LatentDigraph)
S3method(stronglyConnectedComponent,LatentDigraphFixedOrder)
S3method(stronglyConnectedComponent,MixedGraph)
S3method(tianComponent,MixedGraph)
S3method(tianDecompose,MixedGraph)
S3method(toEx,LatentDigraph)
S3method(toEx,MixedGraph)
S3method(toIn,LatentDigraph)
S3method(toIn,MixedGraph)
S3method(trFrom,LatentDigraph)
S3method(trFrom,LatentDigraphFixedOrder)
S3method(trFrom,MixedGraph)
S3method(updateEdgeCapacities,FlowGraph)
S3method(updateVertexCapacities,FlowGraph)
export(FlowGraph)
export(L)
export(LatentDigraph)
export(LatentDigraphFixedOrder)
export(MixedGraph)
export(O)
export(ancestors)
export(ancestralID)
export(ancestralIdentifyStep)
export(bidirectedComponents)
export(children)
export(createLFHtcIdentifier)
export(createLFIdentifierBaseCase)
export(createTrGraph)
export(createTrekFlowGraph)
export(descendants)
export(edgewiseID)
export(edgewiseIdentifyStep)
export(edgewiseTSID)
export(flowBetween)
export(generalGenericID)
export(getHalfTrekSystem)
export(getMixedGraph)
export(getTrekSystem)
export(globalID)
export(graphID)
export(graphID.ancestralID)
export(graphID.genericID)
export(graphID.htcID)
export(graphID.nonHtcID)
export(htcID)
export(htcIdentifyStep)
export(htrFrom)
export(inducedSubgraph)
export(isSibling)
export(latentDigraphHasSimpleNumbering)
export(latentNodes)
export(lfhtcID)
export(lfhtcIdentifyStep)
export(nodes)
export(numLatents)
export(numNodes)
export(numObserved)
export(observedNodes)
export(observedParents)
export(parents)
export(plotMixedGraph)
export(semID)
export(siblings)
export(stronglyConnectedComponent)
export(tianComponent)
export(tianDecompose)
export(tianSigmaForComponent)
export(toEx)
export(toIn)
export(trFrom)
export(trekSeparationIdentifyStep)
export(updateEdgeCapacities)
export(updateVertexCapacities)
export(validateLatentNodesAreSources)
import(igraph)
import(utils)
importFrom(R.methodsS3,setMethodS3)
importFrom(R.oo,setConstructorS3)
importFrom(grDevices,rgb)
importFrom(graphics,plot)
